@@ -1,28 +1,14 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 // Qt
 #include <QtTest>
 // KWin
 #include "../../src/client/connection_thread.h"
-#include "../../src/client/registry.h"
 #include "../../src/client/fullscreen_shell.h"
+#include "../../src/client/registry.h"
 // Wayland
 #include <wayland-client-protocol.h>
 
@@ -59,9 +45,8 @@ void TestWaylandFullscreenShell::init()
     m_westonProcess = new QProcess(this);
     m_westonProcess->setProgram(QStringLiteral("weston"));
 
-    m_westonProcess->setArguments(QStringList({QStringLiteral("--socket=%1").arg(s_socketName),
-                                               QStringLiteral("--backend=headless-backend.so"),
-                                               QStringLiteral("--shell=fullscreen-shell.so")}));
+    m_westonProcess->setArguments(QStringList(
+        {QStringLiteral("--socket=%1").arg(s_socketName), QStringLiteral("--backend=headless-backend.so"), QStringLiteral("--shell=fullscreen-shell.so")}));
     m_westonProcess->start();
     QVERIFY(m_westonProcess->waitForStarted());
     QTest::qWait(500);
@@ -72,7 +57,7 @@ void TestWaylandFullscreenShell::init()
         return;
     }
     QFileSystemWatcher *socketWatcher = new QFileSystemWatcher(QStringList({runtimeDir.absolutePath()}), this);
-    QSignalSpy socketSpy(socketWatcher, SIGNAL(directoryChanged(QString)));
+    QSignalSpy socketSpy(socketWatcher, &QFileSystemWatcher::directoryChanged);
 
     // limit to maximum of 10 waits
     for (int i = 0; i < 10; ++i) {
@@ -99,7 +84,7 @@ void TestWaylandFullscreenShell::testRegistry()
         QSKIP("This test requires a running wayland server");
     }
     KWayland::Client::ConnectionThread connection;
-    QSignalSpy connectedSpy(&connection, SIGNAL(connected()));
+    QSignalSpy connectedSpy(&connection, &KWayland::Client::ConnectionThread::connected);
     connection.setSocketName(s_socketName);
     connection.initConnection();
     QVERIFY(connectedSpy.wait());
@@ -107,7 +92,7 @@ void TestWaylandFullscreenShell::testRegistry()
     KWayland::Client::Registry registry;
     QSignalSpy interfacesAnnouncedSpy(&registry, &KWayland::Client::Registry::interfaceAnnounced);
     QVERIFY(interfacesAnnouncedSpy.isValid());
-    QSignalSpy announced(&registry, SIGNAL(fullscreenShellAnnounced(quint32,quint32)));
+    QSignalSpy announced(&registry, &KWayland::Client::Registry::fullscreenShellAnnounced);
     registry.create(connection.display());
     QVERIFY(registry.isValid());
     registry.setup();
@@ -129,11 +114,12 @@ void TestWaylandFullscreenShell::testRegistry()
 }
 
 void TestWaylandFullscreenShell::testRegistryCreate()
-{    if (m_westonProcess->state() != QProcess::Running) {
+{
+    if (m_westonProcess->state() != QProcess::Running) {
         QSKIP("This test requires a running wayland server");
     }
     KWayland::Client::ConnectionThread connection;
-    QSignalSpy connectedSpy(&connection, SIGNAL(connected()));
+    QSignalSpy connectedSpy(&connection, &KWayland::Client::ConnectionThread::connected);
     connection.setSocketName(s_socketName);
     connection.initConnection();
     QVERIFY(connectedSpy.wait());
@@ -141,7 +127,7 @@ void TestWaylandFullscreenShell::testRegistryCreate()
     KWayland::Client::Registry registry;
     QSignalSpy interfacesAnnouncedSpy(&registry, &KWayland::Client::Registry::interfaceAnnounced);
     QVERIFY(interfacesAnnouncedSpy.isValid());
-    QSignalSpy announced(&registry, SIGNAL(fullscreenShellAnnounced(quint32,quint32)));
+    QSignalSpy announced(&registry, &KWayland::Client::Registry::fullscreenShellAnnounced);
     registry.create(connection.display());
     QVERIFY(registry.isValid());
     registry.setup();
