@@ -1,36 +1,23 @@
-/********************************************************************
-Copyright 2015 Marco Martin <mart@kde.org>
+/*
+    SPDX-FileCopyrightText: 2015 Marco Martin <mart@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 // Qt
-#include <QtTest/QtTest>
+#include <QSignalSpy>
+#include <QTest>
 // KWin
 #include "../../src/client/compositor.h"
 #include "../../src/client/connection_thread.h"
 #include "../../src/client/event_queue.h"
+#include "../../src/client/plasmawindowmanagement.h"
 #include "../../src/client/region.h"
 #include "../../src/client/registry.h"
 #include "../../src/client/surface.h"
-#include "../../src/client/plasmawindowmanagement.h"
-#include "../../src/server/display.h"
 #include "../../src/server/compositor_interface.h"
-#include "../../src/server/region_interface.h"
+#include "../../src/server/display.h"
 #include "../../src/server/plasmawindowmanagement_interface.h"
+#include "../../src/server/region_interface.h"
 #include "../../src/server/surface_interface.h"
 #include <wayland-plasma-window-management-client-protocol.h>
 
@@ -69,6 +56,7 @@ private Q_SLOTS:
     void testGeometry();
     void testIcon();
     void testPid();
+    void testApplicationMenu();
 
     void cleanup();
 
@@ -114,7 +102,7 @@ void TestWindowManagement::init()
 
     // setup connection
     m_connection = new KWayland::Client::ConnectionThread;
-    QSignalSpy connectedSpy(m_connection, SIGNAL(connected()));
+    QSignalSpy connectedSpy(m_connection, &KWayland::Client::ConnectionThread::connected);
     m_connection->setSocketName(s_socketName);
 
     m_thread = new QThread(this);
@@ -130,13 +118,12 @@ void TestWindowManagement::init()
     QVERIFY(m_queue->isValid());
 
     m_registry = new KWayland::Client::Registry(this);
-    QSignalSpy compositorSpy(m_registry, SIGNAL(compositorAnnounced(quint32,quint32)));
+    QSignalSpy compositorSpy(m_registry, &KWayland::Client::Registry::compositorAnnounced);
     QVERIFY(compositorSpy.isValid());
 
-    QSignalSpy windowManagementSpy(m_registry, SIGNAL(plasmaWindowManagementAnnounced(quint32,quint32)));
+    QSignalSpy windowManagementSpy(m_registry, &KWayland::Client::Registry::plasmaWindowManagementAnnounced);
     QVERIFY(windowManagementSpy.isValid());
 
-
     QVERIFY(!m_registry->eventQueue());
     m_registry->setEventQueue(m_queue);
     QCOMPARE(m_registry->eventQueue(), m_queue);
@@ -151,15 +138,16 @@ void TestWindowManagement::init()
     QVERIFY(compositorSpy.wait());
     m_compositor = m_registry->createCompositor(compositorSpy.first().first().value<quint32>(), compositorSpy.first().last().value<quint32>(), this);
 
-
     m_windowManagementInterface = m_display->createPlasmaWindowManagement(m_display);
     m_windowManagementInterface->create();
     QVERIFY(m_windowManagementInterface->isValid());
 
     QVERIFY(windowManagementSpy.wait());
-    m_windowManagement = m_registry->createPlasmaWindowManagement(windowManagementSpy.first().first().value<quint32>(), windowManagementSpy.first().last().value<quint32>(), this);
+    m_windowManagement = m_registry->createPlasmaWindowManagement(windowManagementSpy.first().first().value<quint32>(),
+                                                                  windowManagementSpy.first().last().value<quint32>(),
+                                                                  this);
 
-    QSignalSpy windowSpy(m_windowManagement, SIGNAL(windowCreated(KWayland::Client::PlasmaWindow *)));
+    QSignalSpy windowSpy(m_windowManagement, &KWayland::Client::PlasmaWindowManagement::windowCreated);
     QVERIFY(windowSpy.isValid());
     m_windowInterface = m_windowManagementInterface->createWindow(this);
     m_windowInterface->setPid(1337);
@@ -167,14 +155,14 @@ void TestWindowManagement::init()
     QVERIFY(windowSpy.wait());
     m_window = windowSpy.first().first().value<KWayland::Client::PlasmaWindow *>();
 
-    QSignalSpy serverSurfaceCreated(m_compositorInterface, SIGNAL(surfaceCreated(KWayland::Server::SurfaceInterface*)));
+    QSignalSpy serverSurfaceCreated(m_compositorInterface, &KWayland::Server::CompositorInterface::surfaceCreated);
     QVERIFY(serverSurfaceCreated.isValid());
 
     m_surface = m_compositor->createSurface(this);
     QVERIFY(m_surface);
 
     QVERIFY(serverSurfaceCreated.wait());
-    m_surfaceInterface = serverSurfaceCreated.first().first().value<KWayland::Server::SurfaceInterface*>();
+    m_surfaceInterface = serverSurfaceCreated.first().first().value<KWayland::Server::SurfaceInterface *>();
     QVERIFY(m_surfaceInterface);
 }
 
@@ -182,7 +170,7 @@ void TestWindowManagement::testWindowTitle()
 {
     m_windowInterface->setTitle(QStringLiteral("Test Title"));
 
-    QSignalSpy titleSpy(m_window, SIGNAL(titleChanged()));
+    QSignalSpy titleSpy(m_window, &KWayland::Client::PlasmaWindow::titleChanged);
     QVERIFY(titleSpy.isValid());
 
     QVERIFY(titleSpy.wait());
@@ -194,7 +182,7 @@ void TestWindowManagement::testMinimizedGeometry()
 {
     m_window->setMinimizedGeometry(m_surface, QRect(5, 10, 100, 200));
 
-    QSignalSpy geometrySpy(m_windowInterface, SIGNAL(minimizedGeometriesChanged()));
+    QSignalSpy geometrySpy(m_windowInterface, &KWayland::Server::PlasmaWindowInterface::minimizedGeometriesChanged);
     QVERIFY(geometrySpy.isValid());
 
     QVERIFY(geometrySpy.wait());
@@ -207,7 +195,6 @@ void TestWindowManagement::testMinimizedGeometry()
 
 void TestWindowManagement::cleanup()
 {
-
     if (m_surface) {
         delete m_surface;
         m_surface = nullptr;
@@ -346,7 +333,7 @@ void TestWindowManagement::testCreateAfterUnmap()
     QCoreApplication::instance()->processEvents();
     QCoreApplication::instance()->processEvents(QEventLoop::WaitForMoreEvents);
     QTRY_COMPARE(m_windowManagement->children().count(), 2);
-    auto window = dynamic_cast<KWayland::Client::PlasmaWindow*>(m_windowManagement->children().last());
+    auto window = dynamic_cast<KWayland::Client::PlasmaWindow *>(m_windowManagement->children().last());
     QVERIFY(window);
     // now this is not yet on the server, on the server it will be after next roundtrip
     // which we can trigger by waiting for destroy of the newly created window.
@@ -358,7 +345,7 @@ void TestWindowManagement::testCreateAfterUnmap()
     // the server side created a helper PlasmaWindowInterface with PlasmaWindowManagementInterface as parent
     // it emitted unmapped so we can be sure it will be destroyed directly
     QCOMPARE(m_windowManagementInterface->children().count(), 1);
-    auto helperWindow = qobject_cast<KWayland::Server::PlasmaWindowInterface*>(m_windowManagementInterface->children().first());
+    auto helperWindow = qobject_cast<KWayland::Server::PlasmaWindowInterface *>(m_windowManagementInterface->children().first());
     QVERIFY(helperWindow);
     QSignalSpy helperDestroyedSpy(helperWindow, &QObject::destroyed);
     QVERIFY(helperDestroyedSpy.isValid());
@@ -372,8 +359,8 @@ void TestWindowManagement::testRequests_data()
     QTest::addColumn<ServerWindowSignal>("changedSignal");
     QTest::addColumn<ClientWindowVoidSetter>("requester");
 
-    QTest::newRow("close")  << &PlasmaWindowInterface::closeRequested  << &PlasmaWindow::requestClose;
-    QTest::newRow("move")   << &PlasmaWindowInterface::moveRequested   << &PlasmaWindow::requestMove;
+    QTest::newRow("close") << &PlasmaWindowInterface::closeRequested << &PlasmaWindow::requestClose;
+    QTest::newRow("move") << &PlasmaWindowInterface::moveRequested << &PlasmaWindow::requestMove;
     QTest::newRow("resize") << &PlasmaWindowInterface::resizeRequested << &PlasmaWindow::requestResize;
 }
 
@@ -394,7 +381,7 @@ void TestWindowManagement::testRequestsBoolean_data()
     QTest::addColumn<ServerWindowBooleanSignal>("changedSignal");
     QTest::addColumn<int>("flag");
 
-    QTest::newRow("activate")  << &PlasmaWindowInterface::activeRequested  << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_ACTIVE);
+    QTest::newRow("activate") << &PlasmaWindowInterface::activeRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_ACTIVE);
     QTest::newRow("minimized") << &PlasmaWindowInterface::minimizedRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MINIMIZED);
     QTest::newRow("maximized") << &PlasmaWindowInterface::maximizedRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MAXIMIZED);
     QTest::newRow("fullscreen") << &PlasmaWindowInterface::fullscreenRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_FULLSCREEN);
@@ -411,7 +398,8 @@ void TestWindowManagement::testRequestsBoolean_data()
     QTest::newRow("shaded") << &PlasmaWindowInterface::shadedRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_SHADED);
     QTest::newRow("movable") << &PlasmaWindowInterface::movableRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MOVABLE);
     QTest::newRow("resizable") << &PlasmaWindowInterface::resizableRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_RESIZABLE);
-    QTest::newRow("virtualDesktopChangeable") << &PlasmaWindowInterface::virtualDesktopChangeableRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_VIRTUAL_DESKTOP_CHANGEABLE);
+    QTest::newRow("virtualDesktopChangeable") << &PlasmaWindowInterface::virtualDesktopChangeableRequested
+                                              << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_VIRTUAL_DESKTOP_CHANGEABLE);
 }
 
 void TestWindowManagement::testRequestsBoolean()
@@ -538,7 +526,7 @@ void TestWindowManagement::testParentWindow()
     auto serverTransient = m_windowManagementInterface->createWindow(this);
     serverTransient->setParentWindow(m_windowInterface);
     QVERIFY(windowAddedSpy.wait());
-    auto transient = windowAddedSpy.first().first().value<PlasmaWindow*>();
+    auto transient = windowAddedSpy.first().first().value<PlasmaWindow *>();
     QCOMPARE(transient->parentWindow().data(), parentWindow);
 
     // let's unset the parent
@@ -584,8 +572,9 @@ void TestWindowManagement::testGeometry()
     QCOMPARE(m_window->geometry(), QRect(0, 0, 35, 45));
 
     // let's bind a second PlasmaWindowManagement to verify the initial setting
-    QScopedPointer<PlasmaWindowManagement> pm(m_registry->createPlasmaWindowManagement(m_registry->interface(Registry::Interface::PlasmaWindowManagement).name,
-                                                                                       m_registry->interface(Registry::Interface::PlasmaWindowManagement).version));
+    QScopedPointer<PlasmaWindowManagement> pm(
+        m_registry->createPlasmaWindowManagement(m_registry->interface(Registry::Interface::PlasmaWindowManagement).name,
+                                                 m_registry->interface(Registry::Interface::PlasmaWindowManagement).version));
     QVERIFY(!pm.isNull());
     QSignalSpy windowAddedSpy(pm.data(), &PlasmaWindowManagement::windowCreated);
     QVERIFY(windowAddedSpy.isValid());
@@ -597,17 +586,21 @@ void TestWindowManagement::testGeometry()
 void TestWindowManagement::testIcon()
 {
     using namespace KWayland::Client;
-    QVERIFY(m_window);
+
+    // initially, the server should send us an icon
     QSignalSpy iconChangedSpy(m_window, &PlasmaWindow::iconChanged);
     QVERIFY(iconChangedSpy.isValid());
-    m_windowInterface->setIcon(QIcon());
-    // first goes from themed name to empty
     QVERIFY(iconChangedSpy.wait());
+    QCOMPARE(iconChangedSpy.count(), 1);
     if (!QIcon::hasThemeIcon(QStringLiteral("wayland"))) {
         QEXPECT_FAIL("", "no icon", Continue);
     }
     QCOMPARE(m_window->icon().name(), QStringLiteral("wayland"));
+
+    // first goes from themed name to empty
+    m_windowInterface->setIcon(QIcon());
     QVERIFY(iconChangedSpy.wait());
+    QCOMPARE(iconChangedSpy.count(), 2);
     if (!QIcon::hasThemeIcon(QStringLiteral("wayland"))) {
         QEXPECT_FAIL("", "no icon", Continue);
     }
@@ -618,11 +611,16 @@ void TestWindowManagement::testIcon()
     p.fill(Qt::red);
     m_windowInterface->setIcon(p);
     QVERIFY(iconChangedSpy.wait());
-    QCOMPARE(m_window->icon().pixmap(32, 32), p);
+    QCOMPARE(iconChangedSpy.count(), 3);
+
+    auto clientImage = p.toImage();
+    clientImage.convertTo(p.toImage().format());
+    QCOMPARE(clientImage, p.toImage());
 
     // let's set a themed icon
     m_windowInterface->setIcon(QIcon::fromTheme(QStringLiteral("xorg")));
     QVERIFY(iconChangedSpy.wait());
+    QCOMPARE(iconChangedSpy.count(), 4);
     if (!QIcon::hasThemeIcon(QStringLiteral("xorg"))) {
         QEXPECT_FAIL("", "no icon", Continue);
     }
@@ -635,15 +633,30 @@ void TestWindowManagement::testPid()
     QVERIFY(m_window);
     QVERIFY(m_window->pid() == 1337);
 
-    //test server not setting a PID for whatever reason
+    // test server not setting a PID for whatever reason
     QScopedPointer<KWayland::Server::PlasmaWindowInterface> newWindowInterface(m_windowManagementInterface->createWindow(this));
-    QSignalSpy windowSpy(m_windowManagement, SIGNAL(windowCreated(KWayland::Client::PlasmaWindow *)));
+    QSignalSpy windowSpy(m_windowManagement, &KWayland::Client::PlasmaWindowManagement::windowCreated);
     QVERIFY(windowSpy.wait());
-    QScopedPointer<PlasmaWindow> newWindow( windowSpy.first().first().value<KWayland::Client::PlasmaWindow *>());
+    QScopedPointer<PlasmaWindow> newWindow(windowSpy.first().first().value<KWayland::Client::PlasmaWindow *>());
     QVERIFY(newWindow);
     QVERIFY(newWindow->pid() == 0);
+}
 
+void TestWindowManagement::testApplicationMenu()
+{
+    using namespace KWayland::Client;
 
+    const auto serviceName = QStringLiteral("org.kde.foo");
+    const auto objectPath = QStringLiteral("/org/kde/bar");
+
+    m_windowInterface->setApplicationMenuPaths(serviceName, objectPath);
+
+    QSignalSpy applicationMenuChangedSpy(m_window, &PlasmaWindow::applicationMenuChanged);
+    QVERIFY(applicationMenuChangedSpy.isValid());
+    QVERIFY(applicationMenuChangedSpy.wait());
+
+    QCOMPARE(m_window->applicationMenuServiceName(), serviceName);
+    QCOMPARE(m_window->applicationMenuObjectPath(), objectPath);
 }
 
 QTEST_MAIN(TestWindowManagement)
