@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef WAYLAND_COMPOSITOR_H
 #define WAYLAND_COMPOSITOR_H
 
@@ -32,7 +18,6 @@ namespace KWayland
 {
 namespace Client
 {
-
 class EventQueue;
 class Region;
 class Surface;
@@ -72,7 +57,7 @@ public:
      * Registry::createCompositor.
      **/
     explicit Compositor(QObject *parent = nullptr);
-    virtual ~Compositor();
+    ~Compositor() override;
 
     /**
      * Creates a Compositor for the used QGuiApplication.
@@ -170,8 +155,8 @@ public:
      **/
     std::unique_ptr<Region> createRegion(const QRegion &region);
 
-    operator wl_compositor*();
-    operator wl_compositor*() const;
+    operator wl_compositor *();
+    operator wl_compositor *() const;
 
 Q_SIGNALS:
     /**
