@@ -1,44 +1,29 @@
-/********************************************************************
-Copyright 2015  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2015 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "plasmawindowmanagement.h"
-#include "plasmawindowmodel.h"
-#include "plasmavirtualdesktop.h"
 #include "event_queue.h"
 #include "output.h"
+#include "plasmavirtualdesktop.h"
+#include "plasmawindowmodel.h"
 #include "surface.h"
 #include "wayland_pointer_p.h"
 // Wayland
 #include <wayland-plasma-window-management-client-protocol.h>
 
-#include <QtConcurrentRun>
 #include <QFutureWatcher>
 #include <QTimer>
+#include <QtConcurrentRun>
 #include <qplatformdefs.h>
 
-#include <errno.h>
+#include <cerrno>
 
 namespace KWayland
 {
 namespace Client
 {
-
 class Q_DECL_HIDDEN PlasmaWindowManagement::Private
 {
 public:
@@ -46,16 +31,23 @@ public:
     WaylandPointer<org_kde_plasma_window_management, org_kde_plasma_window_management_destroy> wm;
     EventQueue *queue = nullptr;
     bool showingDesktop = false;
-    QList<PlasmaWindow*> windows;
+    QList<PlasmaWindow *> windows;
     PlasmaWindow *activeWindow = nullptr;
+    QVector<quint32> stackingOrder;
+    QVector<QByteArray> stackingOrderUuids;
 
     void setup(org_kde_plasma_window_management *wm);
 
 private:
     static void showDesktopCallback(void *data, org_kde_plasma_window_management *org_kde_plasma_window_management, uint32_t state);
     static void windowCallback(void *data, org_kde_plasma_window_management *org_kde_plasma_window_management, uint32_t id);
+    static void windowWithUuidCallback(void *data, org_kde_plasma_window_management *org_kde_plasma_window_management, uint32_t id, const char *uuid);
+    static void stackingOrderCallback(void *data, org_kde_plasma_window_management *org_kde_plasma_window_management, wl_array *ids);
+    static void stackingOrderUuidsCallback(void *data, org_kde_plasma_window_management *org_kde_plasma_window_management, const char *uuids);
     void setShowDesktop(bool set);
-    void windowCreated(org_kde_plasma_window *id, quint32 internalId);
+    void windowCreated(org_kde_plasma_window *id, quint32 internalId, const char *uuid);
+    void setStackingOrder(const QVector<quint32> &ids);
+    void setStackingOrder(const QVector<QByteArray> &uuids);
 
     static struct org_kde_plasma_window_management_listener s_listener;
     PlasmaWindowManagement *q;
@@ -64,9 +56,10 @@ private:
 class Q_DECL_HIDDEN PlasmaWindow::Private
 {
 public:
-    Private(org_kde_plasma_window *window, quint32 internalId, PlasmaWindow *q);
+    Private(org_kde_plasma_window *window, quint32 internalId, const char *uuid, PlasmaWindow *q);
     WaylandPointer<org_kde_plasma_window, org_kde_plasma_window_destroy> window;
-    quint32 internalId;
+    quint32 internalId; ///< @deprecated
+    QByteArray uuid;
     QString title;
     QString appId;
     quint32 desktop = 0;
@@ -95,8 +88,11 @@ public:
     QPointer<PlasmaWindow> parentWindow;
     QMetaObject::Connection parentWindowUnmappedConnection;
     QStringList plasmaVirtualDesktops;
+    QStringList plasmaActivities;
     QRect geometry;
     quint32 pid = 0;
+    QString applicationMenuServiceName;
+    QString applicationMenuObjectPath;
 
 private:
     static void titleChangedCallback(void *data, org_kde_plasma_window *window, const char *title);
@@ -112,6 +108,9 @@ private:
     static void iconChangedCallback(void *data, org_kde_plasma_window *org_kde_plasma_window);
     static void virtualDesktopEnteredCallback(void *data, org_kde_plasma_window *org_kde_plasma_window, const char *id);
     static void virtualDesktopLeftCallback(void *data, org_kde_plasma_window *org_kde_plasma_window, const char *id);
+    static void appmenuChangedCallback(void *data, org_kde_plasma_window *org_kde_plasma_window, const char *service_name, const char *object_path);
+    static void activityEnteredCallback(void *data, org_kde_plasma_window *org_kde_plasma_window, const char *id);
+    static void activityLeftCallback(void *data, org_kde_plasma_window *org_kde_plasma_window, const char *id);
     void setActive(bool set);
     void setMinimized(bool set);
     void setMaximized(bool set);
@@ -134,8 +133,9 @@ private:
     void setParentWindow(PlasmaWindow *parentWindow);
     void setPid(const quint32 pid);
 
-    static Private *cast(void *data) {
-        return reinterpret_cast<Private*>(data);
+    static Private *cast(void *data)
+    {
+        return reinterpret_cast<Private *>(data);
     }
 
     PlasmaWindow *q;
@@ -150,7 +150,10 @@ PlasmaWindowManagement::Private::Private(PlasmaWindowManagement *q)
 
 org_kde_plasma_window_management_listener PlasmaWindowManagement::Private::s_listener = {
     showDesktopCallback,
-    windowCallback
+    windowCallback,
+    stackingOrderCallback,
+    stackingOrderUuidsCallback,
+    windowWithUuidCallback,
 };
 
 void PlasmaWindowManagement::Private::setup(org_kde_plasma_window_management *windowManagement)
@@ -163,7 +166,7 @@ void PlasmaWindowManagement::Private::setup(org_kde_plasma_window_management *wi
 
 void PlasmaWindowManagement::Private::showDesktopCallback(void *data, org_kde_plasma_window_management *org_kde_plasma_window_management, uint32_t state)
 {
-    auto wm = reinterpret_cast<PlasmaWindowManagement::Private*>(data);
+    auto wm = reinterpret_cast<PlasmaWindowManagement::Private *>(data);
     Q_ASSERT(wm->wm == org_kde_plasma_window_management);
     switch (state) {
     case ORG_KDE_PLASMA_WINDOW_MANAGEMENT_SHOW_DESKTOP_ENABLED:
@@ -184,66 +187,118 @@ void PlasmaWindowManagement::Private::setShowDesktop(bool set)
         return;
     }
     showingDesktop = set;
-    emit q->showingDesktopChanged(showingDesktop);
+    Q_EMIT q->showingDesktopChanged(showingDesktop);
 }
 
 void PlasmaWindowManagement::Private::windowCallback(void *data, org_kde_plasma_window_management *interface, uint32_t id)
 {
-    auto wm = reinterpret_cast<PlasmaWindowManagement::Private*>(data);
+    auto wm = reinterpret_cast<PlasmaWindowManagement::Private *>(data);
     Q_ASSERT(wm->wm == interface);
     QTimer *timer = new QTimer();
     timer->setSingleShot(true);
     timer->setInterval(0);
-    QObject::connect(timer, &QTimer::timeout, wm->q,
+    QObject::connect(
+        timer,
+        &QTimer::timeout,
+        wm->q,
         [timer, wm, id] {
-            wm->windowCreated(org_kde_plasma_window_management_get_window(wm->wm, id), id);
+            wm->windowCreated(org_kde_plasma_window_management_get_window(wm->wm, id), id, "unavailable");
             timer->deleteLater();
-        }, Qt::QueuedConnection
-    );
+        },
+        Qt::QueuedConnection);
     timer->start();
 }
 
-void PlasmaWindowManagement::Private::windowCreated(org_kde_plasma_window *id, quint32 internalId)
+void PlasmaWindowManagement::Private::windowWithUuidCallback(void *data, org_kde_plasma_window_management *interface, uint32_t id, const char *_uuid)
+{
+    QByteArray uuid(_uuid);
+    auto wm = reinterpret_cast<PlasmaWindowManagement::Private *>(data);
+    Q_ASSERT(wm->wm == interface);
+    QTimer *timer = new QTimer();
+    timer->setSingleShot(true);
+    timer->setInterval(0);
+    QObject::connect(
+        timer,
+        &QTimer::timeout,
+        wm->q,
+        [timer, wm, id, uuid] {
+            wm->windowCreated(org_kde_plasma_window_management_get_window_by_uuid(wm->wm, uuid), id, uuid);
+            timer->deleteLater();
+        },
+        Qt::QueuedConnection);
+    timer->start();
+}
+
+void PlasmaWindowManagement::Private::windowCreated(org_kde_plasma_window *id, quint32 internalId, const char *uuid)
 {
     if (queue) {
         queue->addProxy(id);
     }
-    PlasmaWindow *window = new PlasmaWindow(q, id, internalId);
+    PlasmaWindow *window = new PlasmaWindow(q, id, internalId, uuid);
     window->d->wm = q;
     windows << window;
-    QObject::connect(window, &QObject::destroyed, q,
-        [this, window] {
-            windows.removeAll(window);
+    QObject::connect(window, &QObject::destroyed, q, [this, window] {
+        windows.removeAll(window);
+        if (activeWindow == window) {
+            activeWindow = nullptr;
+            Q_EMIT q->activeWindowChanged();
+        }
+    });
+    QObject::connect(window, &PlasmaWindow::unmapped, q, [this, window] {
+        if (activeWindow == window) {
+            activeWindow = nullptr;
+            Q_EMIT q->activeWindowChanged();
+        }
+    });
+    QObject::connect(window, &PlasmaWindow::activeChanged, q, [this, window] {
+        if (window->isActive()) {
+            if (activeWindow == window) {
+                return;
+            }
+            activeWindow = window;
+            Q_EMIT q->activeWindowChanged();
+        } else {
             if (activeWindow == window) {
                 activeWindow = nullptr;
-                emit q->activeWindowChanged();
+                Q_EMIT q->activeWindowChanged();
             }
         }
-    );
-    QObject::connect(window, &PlasmaWindow::unmapped, q,
-        [this, window] {
-            if (activeWindow == window) {
-                activeWindow = nullptr;
-                emit q->activeWindowChanged();
-            }
-        }
-    );
-    QObject::connect(window, &PlasmaWindow::activeChanged, q,
-        [this, window] {
-            if (window->isActive()) {
-                if (activeWindow == window) {
-                    return;
-                }
-                activeWindow = window;
-                emit q->activeWindowChanged();
-            } else {
-                if (activeWindow == window) {
-                    activeWindow = nullptr;
-                    emit q->activeWindowChanged();
-                }
-            }
-        }
-    );
+    });
+}
+
+void PlasmaWindowManagement::Private::stackingOrderCallback(void *data, org_kde_plasma_window_management *interface, wl_array *ids)
+{
+    auto wm = reinterpret_cast<PlasmaWindowManagement::Private *>(data);
+    Q_ASSERT(wm->wm == interface);
+    QVector<quint32> destination;
+    destination.resize(ids->size / sizeof(uint32_t));
+    memcpy(destination.data(), ids->data, ids->size);
+    wm->setStackingOrder(destination);
+}
+
+void PlasmaWindowManagement::Private::stackingOrderUuidsCallback(void *data, org_kde_plasma_window_management *interface, const char *uuids)
+{
+    auto wm = reinterpret_cast<PlasmaWindowManagement::Private *>(data);
+    Q_ASSERT(wm->wm == interface);
+    wm->setStackingOrder(QByteArray(uuids).split(';').toVector());
+}
+
+void PlasmaWindowManagement::Private::setStackingOrder(const QVector<quint32> &ids)
+{
+    if (stackingOrder == ids) {
+        return;
+    }
+    stackingOrder = ids;
+    Q_EMIT q->stackingOrderChanged();
+}
+
+void PlasmaWindowManagement::Private::setStackingOrder(const QVector<QByteArray> &uuids)
+{
+    if (stackingOrderUuids == uuids) {
+        return;
+    }
+    stackingOrderUuids = uuids;
+    Q_EMIT q->stackingOrderUuidsChanged();
 }
 
 PlasmaWindowManagement::PlasmaWindowManagement(QObject *parent)
@@ -262,7 +317,7 @@ void PlasmaWindowManagement::destroy()
     if (!d->wm) {
         return;
     }
-    emit interfaceAboutToBeDestroyed();
+    Q_EMIT interfaceAboutToBeDestroyed();
     d->wm.destroy();
 }
 
@@ -271,7 +326,7 @@ void PlasmaWindowManagement::release()
     if (!d->wm) {
         return;
     }
-    emit interfaceAboutToBeReleased();
+    Q_EMIT interfaceAboutToBeReleased();
     d->wm.release();
 }
 
@@ -295,12 +350,12 @@ bool PlasmaWindowManagement::isValid() const
     return d->wm.isValid();
 }
 
-PlasmaWindowManagement::operator org_kde_plasma_window_management*()
+PlasmaWindowManagement::operator org_kde_plasma_window_management *()
 {
     return d->wm;
 }
 
-PlasmaWindowManagement::operator org_kde_plasma_window_management*() const
+PlasmaWindowManagement::operator org_kde_plasma_window_management *() const
 {
     return d->wm;
 }
@@ -317,7 +372,9 @@ void PlasmaWindowManagement::showDesktop()
 
 void PlasmaWindowManagement::setShowingDesktop(bool show)
 {
-    org_kde_plasma_window_management_show_desktop(d->wm, show ? ORG_KDE_PLASMA_WINDOW_MANAGEMENT_SHOW_DESKTOP_ENABLED : ORG_KDE_PLASMA_WINDOW_MANAGEMENT_SHOW_DESKTOP_DISABLED);
+    org_kde_plasma_window_management_show_desktop(d->wm,
+                                                  show ? ORG_KDE_PLASMA_WINDOW_MANAGEMENT_SHOW_DESKTOP_ENABLED
+                                                       : ORG_KDE_PLASMA_WINDOW_MANAGEMENT_SHOW_DESKTOP_DISABLED);
 }
 
 bool PlasmaWindowManagement::isShowingDesktop() const
@@ -325,7 +382,7 @@ bool PlasmaWindowManagement::isShowingDesktop() const
     return d->showingDesktop;
 }
 
-QList< PlasmaWindow* > PlasmaWindowManagement::windows() const
+QList<PlasmaWindow *> PlasmaWindowManagement::windows() const
 {
     return d->windows;
 }
@@ -340,6 +397,16 @@ PlasmaWindowModel *PlasmaWindowManagement::createWindowModel()
     return new PlasmaWindowModel(this);
 }
 
+QVector<quint32> PlasmaWindowManagement::stackingOrder() const
+{
+    return d->stackingOrder;
+}
+
+QVector<QByteArray> PlasmaWindowManagement::stackingOrderUuids() const
+{
+    return d->stackingOrderUuids;
+}
+
 org_kde_plasma_window_listener PlasmaWindow::Private::s_listener = {
     titleChangedCallback,
     appIdChangedCallback,
@@ -353,20 +420,33 @@ org_kde_plasma_window_listener PlasmaWindow::Private::s_listener = {
     iconChangedCallback,
     pidChangedCallback,
     virtualDesktopEnteredCallback,
-    virtualDesktopLeftCallback
+    virtualDesktopLeftCallback,
+    appmenuChangedCallback,
+    activityEnteredCallback,
+    activityLeftCallback,
 };
 
+void PlasmaWindow::Private::appmenuChangedCallback(void *data, org_kde_plasma_window *window, const char *service_name, const char *object_path)
+{
+    Q_UNUSED(window)
+
+    Private *p = cast(data);
+
+    p->applicationMenuServiceName = QString::fromUtf8(service_name);
+    p->applicationMenuObjectPath = QString::fromUtf8(object_path);
+
+    Q_EMIT p->q->applicationMenuChanged();
+}
+
 void PlasmaWindow::Private::parentWindowCallback(void *data, org_kde_plasma_window *window, org_kde_plasma_window *parent)
 {
     Q_UNUSED(window)
     Private *p = cast(data);
     const auto windows = p->wm->windows();
-    auto it = std::find_if(windows.begin(), windows.end(),
-        [parent] (const PlasmaWindow *w) {
-            return *w == parent;
-        }
-    );
-    p->setParentWindow(it != windows.end() ? *it : nullptr);
+    auto it = std::find_if(windows.constBegin(), windows.constEnd(), [parent](const PlasmaWindow *w) {
+        return *w == parent;
+    });
+    p->setParentWindow(it != windows.constEnd() ? *it : nullptr);
 }
 
 void PlasmaWindow::Private::windowGeometryCallback(void *data, org_kde_plasma_window *window, int32_t x, int32_t y, uint32_t width, uint32_t height)
@@ -378,7 +458,7 @@ void PlasmaWindow::Private::windowGeometryCallback(void *data, org_kde_plasma_wi
         return;
     }
     p->geometry = geo;
-    emit p->q->geometryChanged();
+    Q_EMIT p->q->geometryChanged();
 }
 
 void PlasmaWindow::Private::setParentWindow(PlasmaWindow *parent)
@@ -387,17 +467,15 @@ void PlasmaWindow::Private::setParentWindow(PlasmaWindow *parent)
     QObject::disconnect(parentWindowUnmappedConnection);
     if (parent && !parent->d->unmapped) {
         parentWindow = QPointer<PlasmaWindow>(parent);
-        parentWindowUnmappedConnection = QObject::connect(parent, &PlasmaWindow::unmapped, q,
-            [this] {
-                setParentWindow(nullptr);
-            }
-        );
+        parentWindowUnmappedConnection = QObject::connect(parent, &PlasmaWindow::unmapped, q, [this] {
+            setParentWindow(nullptr);
+        });
     } else {
         parentWindow = QPointer<PlasmaWindow>();
         parentWindowUnmappedConnection = QMetaObject::Connection();
     }
     if (parentWindow.data() != old.data()) {
-        emit q->parentWindowChanged();
+        Q_EMIT q->parentWindowChanged();
     }
 }
 
@@ -406,7 +484,7 @@ void PlasmaWindow::Private::initialStateCallback(void *data, org_kde_plasma_wind
     Q_UNUSED(window)
     Private *p = cast(data);
     if (!p->unmapped) {
-        emit p->wm->windowCreated(p->q);
+        Q_EMIT p->wm->windowCreated(p->q);
     }
 }
 
@@ -419,7 +497,7 @@ void PlasmaWindow::Private::titleChangedCallback(void *data, org_kde_plasma_wind
         return;
     }
     p->title = t;
-    emit p->q->titleChanged();
+    Q_EMIT p->q->titleChanged();
 }
 
 void PlasmaWindow::Private::appIdChangedCallback(void *data, org_kde_plasma_window *window, const char *appId)
@@ -431,7 +509,7 @@ void PlasmaWindow::Private::appIdChangedCallback(void *data, org_kde_plasma_wind
         return;
     }
     p->appId = s;
-    emit p->q->appIdChanged();
+    Q_EMIT p->q->appIdChanged();
 }
 
 void PlasmaWindow::Private::pidChangedCallback(void *data, org_kde_plasma_window *window, uint32_t pid)
@@ -452,7 +530,7 @@ void PlasmaWindow::Private::virtualDesktopChangedCallback(void *data, org_kde_pl
         return;
     }
     p->desktop = number;
-    emit p->q->virtualDesktopChanged();
+    Q_EMIT p->q->virtualDesktopChanged();
 }
 
 void PlasmaWindow::Private::unmappedCallback(void *data, org_kde_plasma_window *window)
@@ -460,7 +538,7 @@ void PlasmaWindow::Private::unmappedCallback(void *data, org_kde_plasma_window *
     auto p = cast(data);
     Q_UNUSED(window);
     p->unmapped = true;
-    emit p->q->unmapped();
+    Q_EMIT p->q->unmapped();
     p->q->deleteLater();
 }
 
@@ -470,7 +548,10 @@ void PlasmaWindow::Private::virtualDesktopEnteredCallback(void *data, org_kde_pl
     Q_UNUSED(window);
     const QString stringId(QString::fromUtf8(id));
     p->plasmaVirtualDesktops << stringId;
-    emit p->q->plasmaVirtualDesktopEntered(stringId);
+    Q_EMIT p->q->plasmaVirtualDesktopEntered(stringId);
+    if (p->plasmaVirtualDesktops.count() == 1) {
+        Q_EMIT p->q->onAllDesktopsChanged();
+    }
 }
 
 void PlasmaWindow::Private::virtualDesktopLeftCallback(void *data, org_kde_plasma_window *window, const char *id)
@@ -479,7 +560,28 @@ void PlasmaWindow::Private::virtualDesktopLeftCallback(void *data, org_kde_plasm
     Q_UNUSED(window);
     const QString stringId(QString::fromUtf8(id));
     p->plasmaVirtualDesktops.removeAll(stringId);
-    emit p->q->plasmaVirtualDesktopLeft(stringId);
+    Q_EMIT p->q->plasmaVirtualDesktopLeft(stringId);
+    if (p->plasmaVirtualDesktops.isEmpty()) {
+        Q_EMIT p->q->onAllDesktopsChanged();
+    }
+}
+
+void PlasmaWindow::Private::activityEnteredCallback(void *data, org_kde_plasma_window *window, const char *id)
+{
+    auto p = cast(data);
+    Q_UNUSED(window);
+    const QString stringId(QString::fromUtf8(id));
+    p->plasmaActivities << stringId;
+    Q_EMIT p->q->plasmaActivityEntered(stringId);
+}
+
+void PlasmaWindow::Private::activityLeftCallback(void *data, org_kde_plasma_window *window, const char *id)
+{
+    auto p = cast(data);
+    Q_UNUSED(window);
+    const QString stringId(QString::fromUtf8(id));
+    p->plasmaActivities.removeAll(stringId);
+    Q_EMIT p->q->plasmaActivityLeft(stringId);
 }
 
 void PlasmaWindow::Private::stateChangedCallback(void *data, org_kde_plasma_window *window, uint32_t state)
@@ -518,7 +620,7 @@ void PlasmaWindow::Private::themedIconNameChangedCallback(void *data, org_kde_pl
     } else {
         p->icon = QIcon();
     }
-    emit p->q->iconChanged();
+    Q_EMIT p->q->iconChanged();
 }
 
 static int readData(int fd, QByteArray &data)
@@ -547,13 +649,13 @@ void PlasmaWindow::Private::iconChangedCallback(void *data, org_kde_plasma_windo
     auto p = cast(data);
     Q_UNUSED(window);
     int pipeFds[2];
-    if (pipe2(pipeFds, O_CLOEXEC|O_NONBLOCK) != 0) {
+    if (pipe2(pipeFds, O_CLOEXEC | O_NONBLOCK) != 0) {
         return;
     }
     org_kde_plasma_window_get_icon(p->window, pipeFds[1]);
     close(pipeFds[1]);
     const int pipeFd = pipeFds[0];
-    auto readIcon = [pipeFd] () -> QIcon {
+    auto readIcon = [pipeFd]() -> QIcon {
         QByteArray content;
         if (readData(pipeFd, content) != 0) {
             close(pipeFd);
@@ -566,18 +668,16 @@ void PlasmaWindow::Private::iconChangedCallback(void *data, org_kde_plasma_windo
         return icon;
     };
     QFutureWatcher<QIcon> *watcher = new QFutureWatcher<QIcon>(p->q);
-    QObject::connect(watcher, &QFutureWatcher<QIcon>::finished, p->q,
-        [p, watcher] {
-            watcher->deleteLater();
-            QIcon icon = watcher->result();
-            if (!icon.isNull()) {
-                p->icon = icon;
-            } else {
-                p->icon = QIcon::fromTheme(QStringLiteral("wayland"));
-            }
-            emit p->q->iconChanged();
+    QObject::connect(watcher, &QFutureWatcher<QIcon>::finished, p->q, [p, watcher] {
+        watcher->deleteLater();
+        QIcon icon = watcher->result();
+        if (!icon.isNull()) {
+            p->icon = icon;
+        } else {
+            p->icon = QIcon::fromTheme(QStringLiteral("wayland"));
         }
-    );
+        Q_EMIT p->q->iconChanged();
+    });
     watcher->setFuture(QtConcurrent::run(readIcon));
 }
 
@@ -587,7 +687,7 @@ void PlasmaWindow::Private::setActive(bool set)
         return;
     }
     active = set;
-    emit q->activeChanged();
+    Q_EMIT q->activeChanged();
 }
 
 void PlasmaWindow::Private::setFullscreen(bool set)
@@ -596,7 +696,7 @@ void PlasmaWindow::Private::setFullscreen(bool set)
         return;
     }
     fullscreen = set;
-    emit q->fullscreenChanged();
+    Q_EMIT q->fullscreenChanged();
 }
 
 void PlasmaWindow::Private::setKeepAbove(bool set)
@@ -605,7 +705,7 @@ void PlasmaWindow::Private::setKeepAbove(bool set)
         return;
     }
     keepAbove = set;
-    emit q->keepAboveChanged();
+    Q_EMIT q->keepAboveChanged();
 }
 
 void PlasmaWindow::Private::setKeepBelow(bool set)
@@ -614,7 +714,7 @@ void PlasmaWindow::Private::setKeepBelow(bool set)
         return;
     }
     keepBelow = set;
-    emit q->keepBelowChanged();
+    Q_EMIT q->keepBelowChanged();
 }
 
 void PlasmaWindow::Private::setMaximized(bool set)
@@ -623,7 +723,7 @@ void PlasmaWindow::Private::setMaximized(bool set)
         return;
     }
     maximized = set;
-    emit q->maximizedChanged();
+    Q_EMIT q->maximizedChanged();
 }
 
 void PlasmaWindow::Private::setMinimized(bool set)
@@ -632,7 +732,7 @@ void PlasmaWindow::Private::setMinimized(bool set)
         return;
     }
     minimized = set;
-    emit q->minimizedChanged();
+    Q_EMIT q->minimizedChanged();
 }
 
 void PlasmaWindow::Private::setOnAllDesktops(bool set)
@@ -641,7 +741,7 @@ void PlasmaWindow::Private::setOnAllDesktops(bool set)
         return;
     }
     onAllDesktops = set;
-    emit q->onAllDesktopsChanged();
+    Q_EMIT q->onAllDesktopsChanged();
 }
 
 void PlasmaWindow::Private::setDemandsAttention(bool set)
@@ -650,7 +750,7 @@ void PlasmaWindow::Private::setDemandsAttention(bool set)
         return;
     }
     demandsAttention = set;
-    emit q->demandsAttentionChanged();
+    Q_EMIT q->demandsAttentionChanged();
 }
 
 void PlasmaWindow::Private::setCloseable(bool set)
@@ -659,7 +759,7 @@ void PlasmaWindow::Private::setCloseable(bool set)
         return;
     }
     closeable = set;
-    emit q->closeableChanged();
+    Q_EMIT q->closeableChanged();
 }
 
 void PlasmaWindow::Private::setFullscreenable(bool set)
@@ -668,7 +768,7 @@ void PlasmaWindow::Private::setFullscreenable(bool set)
         return;
     }
     fullscreenable = set;
-    emit q->fullscreenableChanged();
+    Q_EMIT q->fullscreenableChanged();
 }
 
 void PlasmaWindow::Private::setMaximizeable(bool set)
@@ -677,7 +777,7 @@ void PlasmaWindow::Private::setMaximizeable(bool set)
         return;
     }
     maximizeable = set;
-    emit q->maximizeableChanged();
+    Q_EMIT q->maximizeableChanged();
 }
 
 void PlasmaWindow::Private::setMinimizeable(bool set)
@@ -686,7 +786,7 @@ void PlasmaWindow::Private::setMinimizeable(bool set)
         return;
     }
     minimizeable = set;
-    emit q->minimizeableChanged();
+    Q_EMIT q->minimizeableChanged();
 }
 
 void PlasmaWindow::Private::setSkipTaskbar(bool skip)
@@ -695,7 +795,7 @@ void PlasmaWindow::Private::setSkipTaskbar(bool skip)
         return;
     }
     skipTaskbar = skip;
-    emit q->skipTaskbarChanged();
+    Q_EMIT q->skipTaskbarChanged();
 }
 
 void PlasmaWindow::Private::setSkipSwitcher(bool skip)
@@ -704,7 +804,7 @@ void PlasmaWindow::Private::setSkipSwitcher(bool skip)
         return;
     }
     skipSwitcher = skip;
-    emit q->skipSwitcherChanged();
+    Q_EMIT q->skipSwitcherChanged();
 }
 
 void PlasmaWindow::Private::setShadeable(bool set)
@@ -713,7 +813,7 @@ void PlasmaWindow::Private::setShadeable(bool set)
         return;
     }
     shadeable = set;
-    emit q->shadeableChanged();
+    Q_EMIT q->shadeableChanged();
 }
 
 void PlasmaWindow::Private::setShaded(bool set)
@@ -722,7 +822,7 @@ void PlasmaWindow::Private::setShaded(bool set)
         return;
     }
     shaded = set;
-    emit q->shadedChanged();
+    Q_EMIT q->shadedChanged();
 }
 
 void PlasmaWindow::Private::setMovable(bool set)
@@ -731,7 +831,7 @@ void PlasmaWindow::Private::setMovable(bool set)
         return;
     }
     movable = set;
-    emit q->movableChanged();
+    Q_EMIT q->movableChanged();
 }
 
 void PlasmaWindow::Private::setResizable(bool set)
@@ -740,7 +840,7 @@ void PlasmaWindow::Private::setResizable(bool set)
         return;
     }
     resizable = set;
-    emit q->resizableChanged();
+    Q_EMIT q->resizableChanged();
 }
 
 void PlasmaWindow::Private::setVirtualDesktopChangeable(bool set)
@@ -749,20 +849,22 @@ void PlasmaWindow::Private::setVirtualDesktopChangeable(bool set)
         return;
     }
     virtualDesktopChangeable = set;
-    emit q->virtualDesktopChangeableChanged();
+    Q_EMIT q->virtualDesktopChangeableChanged();
 }
 
-PlasmaWindow::Private::Private(org_kde_plasma_window *w, quint32 internalId, PlasmaWindow *q)
+PlasmaWindow::Private::Private(org_kde_plasma_window *w, quint32 internalId, const char *uuid, PlasmaWindow *q)
     : internalId(internalId)
+    , uuid(uuid)
     , q(q)
 {
+    Q_ASSERT(!this->uuid.isEmpty());
     window.setup(w);
     org_kde_plasma_window_add_listener(w, &s_listener, this);
 }
 
-PlasmaWindow::PlasmaWindow(PlasmaWindowManagement *parent, org_kde_plasma_window *window, quint32 internalId)
+PlasmaWindow::PlasmaWindow(PlasmaWindowManagement *parent, org_kde_plasma_window *window, quint32 internalId, const char *uuid)
     : QObject(parent)
-    , d(new Private(window, internalId, this))
+    , d(new Private(window, internalId, uuid, this))
 {
 }
 
@@ -786,12 +888,12 @@ bool PlasmaWindow::isValid() const
     return d->window.isValid();
 }
 
-PlasmaWindow::operator org_kde_plasma_window*() const
+PlasmaWindow::operator org_kde_plasma_window *() const
 {
     return d->window;
 }
 
-PlasmaWindow::operator org_kde_plasma_window*()
+PlasmaWindow::operator org_kde_plasma_window *()
 {
     return d->window;
 }
@@ -848,13 +950,12 @@ bool PlasmaWindow::isMinimized() const
 
 bool PlasmaWindow::isOnAllDesktops() const
 {
-    //from protocol version 8 virtual desktops are managed by plasmaVirtualDesktops
+    // from protocol version 8 virtual desktops are managed by plasmaVirtualDesktops
     if (org_kde_plasma_window_get_version(d->window) < 8) {
         return d->onAllDesktops;
     } else {
         return d->plasmaVirtualDesktops.isEmpty();
     }
-    
 }
 
 bool PlasmaWindow::isDemandingAttention() const
@@ -922,11 +1023,19 @@ bool PlasmaWindow::isVirtualDesktopChangeable() const
     return d->virtualDesktopChangeable;
 }
 
+QString PlasmaWindow::applicationMenuObjectPath() const
+{
+    return d->applicationMenuObjectPath;
+}
+
+QString PlasmaWindow::applicationMenuServiceName() const
+{
+    return d->applicationMenuServiceName;
+}
+
 void PlasmaWindow::requestActivate()
 {
-    org_kde_plasma_window_set_state(d->window,
-        ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_ACTIVE,
-        ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_ACTIVE);
+    org_kde_plasma_window_set_state(d->window, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_ACTIVE, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_ACTIVE);
 }
 
 void PlasmaWindow::requestClose()
@@ -952,52 +1061,36 @@ void PlasmaWindow::requestVirtualDesktop(quint32 desktop)
 void PlasmaWindow::requestToggleKeepAbove()
 {
     if (d->keepAbove) {
-        org_kde_plasma_window_set_state(d->window,
-            ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_KEEP_ABOVE,
-            0);
+        org_kde_plasma_window_set_state(d->window, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_KEEP_ABOVE, 0);
     } else {
-        org_kde_plasma_window_set_state(d->window,
-            ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_KEEP_ABOVE,
-            ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_KEEP_ABOVE);
+        org_kde_plasma_window_set_state(d->window, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_KEEP_ABOVE, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_KEEP_ABOVE);
     }
 }
 
 void PlasmaWindow::requestToggleKeepBelow()
 {
     if (d->keepBelow) {
-        org_kde_plasma_window_set_state(d->window,
-            ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_KEEP_BELOW,
-            0);
+        org_kde_plasma_window_set_state(d->window, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_KEEP_BELOW, 0);
     } else {
-        org_kde_plasma_window_set_state(d->window,
-            ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_KEEP_BELOW,
-            ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_KEEP_BELOW);
+        org_kde_plasma_window_set_state(d->window, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_KEEP_BELOW, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_KEEP_BELOW);
     }
 }
 
 void PlasmaWindow::requestToggleMinimized()
 {
     if (d->minimized) {
-        org_kde_plasma_window_set_state(d->window,
-            ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MINIMIZED,
-            0);
+        org_kde_plasma_window_set_state(d->window, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MINIMIZED, 0);
     } else {
-        org_kde_plasma_window_set_state(d->window,
-            ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MINIMIZED,
-            ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MINIMIZED);
+        org_kde_plasma_window_set_state(d->window, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MINIMIZED, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MINIMIZED);
     }
 }
 
 void PlasmaWindow::requestToggleMaximized()
 {
     if (d->maximized) {
-        org_kde_plasma_window_set_state(d->window,
-            ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MAXIMIZED,
-            0);
+        org_kde_plasma_window_set_state(d->window, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MAXIMIZED, 0);
     } else {
-        org_kde_plasma_window_set_state(d->window,
-            ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MAXIMIZED,
-            ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MAXIMIZED);
+        org_kde_plasma_window_set_state(d->window, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MAXIMIZED, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MAXIMIZED);
     }
 }
 
@@ -1014,13 +1107,9 @@ void PlasmaWindow::unsetMinimizedGeometry(Surface *panel)
 void PlasmaWindow::requestToggleShaded()
 {
     if (d->shaded) {
-        org_kde_plasma_window_set_state(d->window,
-            ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_SHADED,
-            0);
+        org_kde_plasma_window_set_state(d->window, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_SHADED, 0);
     } else {
-        org_kde_plasma_window_set_state(d->window,
-            ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_SHADED,
-            ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_SHADED);
+        org_kde_plasma_window_set_state(d->window, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_SHADED, ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_SHADED);
     }
 }
 
@@ -1029,6 +1118,11 @@ quint32 PlasmaWindow::internalId() const
     return d->internalId;
 }
 
+QByteArray PlasmaWindow::uuid() const
+{
+    return d->uuid;
+}
+
 QPointer<PlasmaWindow> PlasmaWindow::parentWindow() const
 {
     return d->parentWindow;
@@ -1059,5 +1153,173 @@ QStringList PlasmaWindow::plasmaVirtualDesktops() const
     return d->plasmaVirtualDesktops;
 }
 
+void PlasmaWindow::requestEnterActivity(const QString &id)
+{
+    org_kde_plasma_window_request_enter_activity(d->window, id.toUtf8());
+}
+
+void PlasmaWindow::requestLeaveActivity(const QString &id)
+{
+    org_kde_plasma_window_request_leave_activity(d->window, id.toUtf8());
+}
+
+QStringList PlasmaWindow::plasmaActivities() const
+{
+    return d->plasmaActivities;
+}
+
+void PlasmaWindow::sendToOutput(KWayland::Client::Output *output) const
+{
+    if (org_kde_plasma_window_get_version(d->window) >= ORG_KDE_PLASMA_WINDOW_SEND_TO_OUTPUT_SINCE_VERSION) {
+        org_kde_plasma_window_send_to_output(d->window, *output);
+    }
+}
+
+class Q_DECL_HIDDEN PlasmaActivationFeedback::Private
+{
+public:
+    Private(PlasmaActivationFeedback *q);
+    WaylandPointer<org_kde_plasma_activation_feedback, org_kde_plasma_activation_feedback_destroy> feedback;
+    EventQueue *queue = nullptr;
+
+    void setup(org_kde_plasma_activation_feedback *feedback);
+
+private:
+    static void activationCallback(void *data, struct org_kde_plasma_activation_feedback *feedback, struct org_kde_plasma_activation *id);
+
+    static struct org_kde_plasma_activation_feedback_listener s_listener;
+    PlasmaActivationFeedback *q;
+};
+
+PlasmaActivationFeedback::Private::Private(PlasmaActivationFeedback *q)
+    : q(q)
+{
+}
+
+org_kde_plasma_activation_feedback_listener PlasmaActivationFeedback::Private::s_listener = {
+    activationCallback,
+};
+
+void PlasmaActivationFeedback::Private::activationCallback(void *data, org_kde_plasma_activation_feedback *interface, struct org_kde_plasma_activation *id)
+{
+    auto feedbackPrivate = reinterpret_cast<PlasmaActivationFeedback::Private *>(data);
+    Q_ASSERT(feedbackPrivate->feedback == interface);
+    auto activation = new PlasmaActivation(feedbackPrivate->q, id);
+    Q_EMIT feedbackPrivate->q->activation(activation);
+}
+
+void PlasmaActivationFeedback::Private::setup(org_kde_plasma_activation_feedback *m)
+{
+    Q_ASSERT(!feedback);
+    Q_ASSERT(m);
+    feedback.setup(m);
+    org_kde_plasma_activation_feedback_add_listener(m, &s_listener, this);
+}
+
+PlasmaActivationFeedback::PlasmaActivationFeedback(QObject *parent)
+    : QObject(parent)
+    , d(new Private(this))
+{
+}
+
+PlasmaActivationFeedback::~PlasmaActivationFeedback()
+{
+    release();
+}
+
+void PlasmaActivationFeedback::destroy()
+{
+    if (!d->feedback) {
+        return;
+    }
+    Q_EMIT interfaceAboutToBeDestroyed();
+    d->feedback.destroy();
+}
+
+void PlasmaActivationFeedback::release()
+{
+    if (!d->feedback) {
+        return;
+    }
+    Q_EMIT interfaceAboutToBeReleased();
+    d->feedback.release();
+}
+
+void PlasmaActivationFeedback::setup(org_kde_plasma_activation_feedback *wm)
+{
+    d->setup(wm);
+}
+
+void PlasmaActivationFeedback::setEventQueue(EventQueue *queue)
+{
+    d->queue = queue;
+}
+
+EventQueue *PlasmaActivationFeedback::eventQueue()
+{
+    return d->queue;
+}
+
+bool PlasmaActivationFeedback::isValid() const
+{
+    return d->feedback.isValid();
+}
+
+PlasmaActivationFeedback::operator org_kde_plasma_activation_feedback *()
+{
+    return d->feedback;
+}
+
+PlasmaActivationFeedback::operator org_kde_plasma_activation_feedback *() const
+{
+    return d->feedback;
+}
+
+class Q_DECL_HIDDEN PlasmaActivation::Private
+{
+public:
+    Private(org_kde_plasma_activation *activation, PlasmaActivation *q)
+        : activation(activation)
+    {
+        org_kde_plasma_activation_add_listener(activation, &s_listener, q);
+    }
+
+    static PlasmaActivation *cast(void *data)
+    {
+        return reinterpret_cast<PlasmaActivation *>(data);
+    }
+    WaylandPointer<org_kde_plasma_activation, org_kde_plasma_activation_destroy> activation;
+
+    static org_kde_plasma_activation_listener s_listener;
+    static void app_idCallback(void *data, struct org_kde_plasma_activation *org_kde_plasma_activation, const char *app_id);
+    static void finishedCallback(void *data, struct org_kde_plasma_activation *org_kde_plasma_activation);
+};
+
+org_kde_plasma_activation_listener PlasmaActivation::Private::s_listener = {
+    app_idCallback,
+    finishedCallback,
+};
+
+void PlasmaActivation::Private::app_idCallback(void *data, org_kde_plasma_activation *activation, const char *appId)
+{
+    Q_UNUSED(activation)
+    Q_EMIT cast(data)->applicationId(QString::fromUtf8(appId));
+}
+
+void PlasmaActivation::Private::finishedCallback(void *data, org_kde_plasma_activation *)
+{
+    auto q = cast(data);
+    Q_EMIT q->finished();
+    Q_EMIT q->deleteLater();
+    q->d->activation.release();
+}
+
+PlasmaActivation::PlasmaActivation(PlasmaActivationFeedback *parent, org_kde_plasma_activation *activation)
+    : QObject(parent)
+    , d(new PlasmaActivation::Private(activation, this))
+{
+}
+
+PlasmaActivation::~PlasmaActivation() = default;
 }
 }
