@@ -21,7 +21,6 @@ namespace KWayland
 {
 namespace Client
 {
-
 class EventQueue;
 class PointerPinchGesture;
 class Pointer;
@@ -65,7 +64,7 @@ public:
      * Registry::createPointerGestures.
      **/
     explicit PointerGestures(QObject *parent = nullptr);
-    virtual ~PointerGestures();
+    ~PointerGestures() override;
 
     /**
      * Setup this PointerGestures to manage the @p pointergestures.
@@ -119,8 +118,8 @@ public:
      **/
     PointerPinchGesture *createPinchGesture(Pointer *pointer, QObject *parent = nullptr);
 
-    operator zwp_pointer_gestures_v1*();
-    operator zwp_pointer_gestures_v1*() const;
+    operator zwp_pointer_gestures_v1 *();
+    operator zwp_pointer_gestures_v1 *() const;
 
 Q_SIGNALS:
     /**
@@ -163,7 +162,7 @@ class KWAYLANDCLIENT_EXPORT PointerSwipeGesture : public QObject
 {
     Q_OBJECT
 public:
-    virtual ~PointerSwipeGesture();
+    ~PointerSwipeGesture() override;
 
     /**
      * Setup this PointerSwipeGesture to manage the @p pointerswipegesture.
@@ -211,8 +210,8 @@ public:
      **/
     QPointer<Surface> surface() const;
 
-    operator zwp_pointer_gesture_swipe_v1*();
-    operator zwp_pointer_gesture_swipe_v1*() const;
+    operator zwp_pointer_gesture_swipe_v1 *();
+    operator zwp_pointer_gesture_swipe_v1 *() const;
 
 Q_SIGNALS:
     /**
@@ -291,7 +290,7 @@ class KWAYLANDCLIENT_EXPORT PointerPinchGesture : public QObject
 {
     Q_OBJECT
 public:
-    virtual ~PointerPinchGesture();
+    ~PointerPinchGesture() override;
 
     /**
      * Setup this PointerPinchGesture to manage the @p pointerpinchgesture.
@@ -339,8 +338,8 @@ public:
      **/
     QPointer<Surface> surface() const;
 
-    operator zwp_pointer_gesture_pinch_v1*();
-    operator zwp_pointer_gesture_pinch_v1*() const;
+    operator zwp_pointer_gesture_pinch_v1 *();
+    operator zwp_pointer_gesture_pinch_v1 *() const;
 
 Q_SIGNALS:
     /**
@@ -394,7 +393,6 @@ private:
     QScopedPointer<Private> d;
 };
 
-
 }
 }
 
