@@ -18,7 +18,6 @@ namespace KWayland
 {
 namespace Client
 {
-
 class EventQueue;
 class Surface;
 class ServerSideDecoration;
@@ -58,7 +57,7 @@ public:
      * Registry::createServerSideDecorationManager.
      **/
     explicit ServerSideDecorationManager(QObject *parent = nullptr);
-    virtual ~ServerSideDecorationManager();
+    ~ServerSideDecorationManager() override;
 
     /**
      * Setup this ServerSideDecorationManager to manage the @p serversidedecorationmanager.
@@ -106,8 +105,8 @@ public:
     ServerSideDecoration *create(Surface *surface, QObject *parent = nullptr);
     ServerSideDecoration *create(wl_surface *surface, QObject *parent = nullptr);
 
-    operator org_kde_kwin_server_decoration_manager*();
-    operator org_kde_kwin_server_decoration_manager*() const;
+    operator org_kde_kwin_server_decoration_manager *();
+    operator org_kde_kwin_server_decoration_manager *() const;
 
 Q_SIGNALS:
     /**
@@ -135,7 +134,7 @@ class KWAYLANDCLIENT_EXPORT ServerSideDecoration : public QObject
 {
     Q_OBJECT
 public:
-    virtual ~ServerSideDecoration();
+    ~ServerSideDecoration() override;
 
     /**
      * Setup this ServerSideDecoration to manage the @p serversidedecoration.
@@ -213,8 +212,8 @@ public:
      **/
     Mode defaultMode() const;
 
-    operator org_kde_kwin_server_decoration*();
-    operator org_kde_kwin_server_decoration*() const;
+    operator org_kde_kwin_server_decoration *();
+    operator org_kde_kwin_server_decoration *() const;
 
 Q_SIGNALS:
     /**
@@ -231,7 +230,6 @@ private:
     QScopedPointer<Private> d;
 };
 
-
 }
 }
 
