@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2015  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2015 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef WAYLAND_TOUCH_H
 #define WAYLAND_TOUCH_H
 
@@ -31,10 +17,12 @@ namespace KWayland
 {
 namespace Client
 {
-
 class Surface;
 class Touch;
 
+/**
+ * TODO
+ */
 class KWAYLANDCLIENT_EXPORT TouchPoint
 {
 public:
@@ -101,7 +89,7 @@ class KWAYLANDCLIENT_EXPORT Touch : public QObject
     Q_OBJECT
 public:
     explicit Touch(QObject *parent = nullptr);
-    virtual ~Touch();
+    ~Touch() override;
 
     /**
      * @returns @c true if managing a wl_pointer.
@@ -142,10 +130,10 @@ public:
      * The TouchPoints of the latest touch event sequence.
      * Only valid till the next touch event sequence is started
      **/
-    QVector<TouchPoint*> sequence() const;
+    QVector<TouchPoint *> sequence() const;
 
-    operator wl_touch*();
-    operator wl_touch*() const;
+    operator wl_touch *();
+    operator wl_touch *() const;
 
 Q_SIGNALS:
     /**
@@ -188,6 +176,6 @@ private:
 }
 }
 
-Q_DECLARE_METATYPE(KWayland::Client::TouchPoint*)
+Q_DECLARE_METATYPE(KWayland::Client::TouchPoint *)
 
 #endif
