@@ -1,38 +1,25 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "keyboard_interface.h"
-#include "keyboard_interface_p.h"
 #include "display.h"
+#include "keyboard_interface_p.h"
 #include "seat_interface.h"
 #include "surface_interface.h"
 // Qt
+#include <QTemporaryFile>
 #include <QVector>
 // Wayland
 #include <wayland-server.h>
 
+#include <unistd.h>
+
 namespace KWayland
 {
-
 namespace Server
 {
-
 KeyboardInterface::Private::Private(SeatInterface *s, wl_resource *parentResource, KeyboardInterface *q)
     : Resource::Private(q, s, parentResource, &wl_keyboard_interface, &s_interface)
     , seat(s)
@@ -62,7 +49,7 @@ void KeyboardInterface::Private::sendEnter(SurfaceInterface *surface, quint32 se
     wl_array_init(&keys);
     const auto states = seat->pressedKeys();
     for (auto it = states.constBegin(); it != states.constEnd(); ++it) {
-        uint32_t *k = reinterpret_cast<uint32_t*>(wl_array_add(&keys, sizeof(uint32_t)));
+        uint32_t *k = reinterpret_cast<uint32_t *>(wl_array_add(&keys, sizeof(uint32_t)));
         *k = *it;
     }
     wl_keyboard_send_enter(resource, serial, surface->resource(), &keys);
@@ -90,6 +77,29 @@ void KeyboardInterface::setKeymap(int fd, quint32 size)
     d->sendKeymap(fd, size);
 }
 
+void KeyboardInterface::setKeymap(const QByteArray &content)
+{
+    QScopedPointer<QTemporaryFile> tmp{new QTemporaryFile(this)};
+    if (!tmp->open()) {
+        return;
+    }
+    unlink(tmp->fileName().toUtf8().constData());
+    if (!tmp->resize(content.size())) {
+        return;
+    }
+    uchar *address = tmp->map(0, content.size());
+    if (!address) {
+        return;
+    }
+    if (qstrncpy(reinterpret_cast<char *>(address), content.constData(), content.size() + 1) == nullptr) {
+        return;
+    }
+    tmp->unmap(address);
+    Q_D();
+    d->sendKeymap(tmp->handle(), content.size());
+    d->keymap.swap(tmp);
+}
+
 void KeyboardInterface::Private::sendKeymap(int fd, quint32 size)
 {
     if (!resource) {
@@ -121,16 +131,14 @@ void KeyboardInterface::setFocusedSurface(SurfaceInterface *surface, quint32 ser
     if (!d->focusedSurface) {
         return;
     }
-    d->destroyConnection = connect(d->focusedSurface, &Resource::aboutToBeUnbound, this,
-        [this] {
-            Q_D();
-            if (d->resource) {
-                wl_keyboard_send_leave(d->resource, d->global->display()->nextSerial(), d->focusedSurface->resource());
-            }
-            d->focusedSurface = nullptr;
-            d->focusedChildSurface.clear();
+    d->destroyConnection = connect(d->focusedSurface, &Resource::aboutToBeUnbound, this, [this] {
+        Q_D();
+        if (d->resource) {
+            wl_keyboard_send_leave(d->resource, d->global->display()->nextSerial(), d->focusedSurface->resource());
         }
-    );
+        d->focusedSurface = nullptr;
+        d->focusedChildSurface.clear();
+    });
     d->focusedChildSurface = QPointer<SurfaceInterface>(surface);
 
     d->sendEnter(d->focusedSurface, serial);
@@ -185,7 +193,7 @@ SurfaceInterface *KeyboardInterface::focusedSurface() const
 
 KeyboardInterface::Private *KeyboardInterface::d_func() const
 {
-    return reinterpret_cast<Private*>(d.data());
+    return reinterpret_cast<Private *>(d.data());
 }
 
 }
