@@ -12,7 +12,6 @@ namespace KWayland
 {
 namespace Server
 {
-
 /**
  * @class RemoteBufferInterface
  * @brief Internally used class. Holds data of passed buffer and client resource. Also controls buffer lifecycle.
@@ -22,7 +21,7 @@ class RemoteBufferInterface : public Resource
 {
     Q_OBJECT
 public:
-    virtual ~RemoteBufferInterface() = default;
+    ~RemoteBufferInterface() override = default;
 
     /**
      * Sends GBM fd to the client.
