@@ -1,25 +1,11 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "resource.h"
-#include "resource_p.h"
 #include "clientconnection.h"
+#include "resource_p.h"
 
 #include <wayland-server.h>
 
@@ -27,8 +13,7 @@ namespace KWayland
 {
 namespace Server
 {
-
-QList<Resource::Private*> Resource::Private::s_allResources;
+QList<Resource::Private *> Resource::Private::s_allResources;
 
 Resource::Private::Private(Resource *q, Global *g, wl_resource *parentResource, const wl_interface *interface, const void *implementation)
     : parentResource(parentResource)
@@ -63,12 +48,12 @@ void Resource::Private::create(ClientConnection *c, quint32 version, quint32 id)
 void Resource::Private::unbind(wl_resource *r)
 {
     Private *p = cast<Private>(r);
+    Q_EMIT p->q->aboutToBeUnbound();
     p->resource = nullptr;
-    emit p->q->unbound();
+    Q_EMIT p->q->unbound();
     p->q->deleteLater();
 }
 
-
 void Resource::Private::resourceDestroyedCallback(wl_client *client, wl_resource *resource)
 {
     Q_UNUSED(client)
