@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "../src/server/buffer_interface.h"
 #include "../src/server/compositor_interface.h"
 #include "../src/server/datadevicemanager_interface.h"
@@ -36,17 +22,15 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include <QWidget>
 #include <QtConcurrent>
 
-#include <unistd.h>
 #include <iostream>
+#include <unistd.h>
 
 static int startXServer()
 {
     const QByteArray process = QByteArrayLiteral("Xwayland");
     int pipeFds[2];
     if (pipe(pipeFds) != 0) {
-        std::cerr << "FATAL ERROR failed to create pipe to start X Server "
-                  << process.constData()
-                  << std::endl;
+        std::cerr << "FATAL ERROR failed to create pipe to start X Server " << process.constData() << std::endl;
         exit(1);
     }
 
@@ -57,7 +41,7 @@ static int startXServer()
         close(pipeFds[0]);
         char fdbuf[16];
         sprintf(fdbuf, "%d", pipeFds[1]);
-        execlp(process.constData(), process.constData(), "-displayfd", fdbuf, "-rootless", (char *)0);
+        execlp(process.constData(), process.constData(), "-displayfd", fdbuf, "-rootless", (char *)nullptr);
         close(pipeFds[1]);
         exit(20);
     }
@@ -77,7 +61,7 @@ static void readDisplayFromPipe(int pipe)
     QByteArray displayNumber = readPipe.readLine();
 
     displayNumber.prepend(QByteArray(":"));
-    displayNumber.remove(displayNumber.size() -1, 1);
+    displayNumber.remove(displayNumber.size() - 1, 1);
     std::cout << "X-Server started on display " << displayNumber.constData() << std::endl;
 
     setenv("DISPLAY", displayNumber.constData(), true);
@@ -91,7 +75,7 @@ class CompositorWindow : public QWidget
     Q_OBJECT
 public:
     explicit CompositorWindow(QWidget *parent = nullptr);
-    virtual ~CompositorWindow();
+    ~CompositorWindow() override;
 
     void surfaceCreated(KWayland::Server::ShellSurfaceInterface *surface);
 
@@ -108,7 +92,7 @@ protected:
 
 private:
     void updateFocus();
-    QList<KWayland::Server::ShellSurfaceInterface*> m_stackingOrder;
+    QList<KWayland::Server::ShellSurfaceInterface *> m_stackingOrder;
     QPointer<KWayland::Server::SeatInterface> m_seat;
 };
 
@@ -124,28 +108,22 @@ void CompositorWindow::surfaceCreated(KWayland::Server::ShellSurfaceInterface *s
 {
     using namespace KWayland::Server;
     m_stackingOrder << surface;
-    connect(surface, &ShellSurfaceInterface::fullscreenChanged, this,
-        [surface, this](bool fullscreen) {
-            if (fullscreen) {
-                surface->requestSize(size());
-            }
+    connect(surface, &ShellSurfaceInterface::fullscreenChanged, this, [surface, this](bool fullscreen) {
+        if (fullscreen) {
+            surface->requestSize(size());
         }
-    );
-    connect(surface, &ShellSurfaceInterface::maximizedChanged, this,
-        [surface, this](bool maximized) {
-            if (maximized) {
-                surface->requestSize(size());
-            }
+    });
+    connect(surface, &ShellSurfaceInterface::maximizedChanged, this, [surface, this](bool maximized) {
+        if (maximized) {
+            surface->requestSize(size());
         }
-    );
+    });
     connect(surface->surface(), &SurfaceInterface::damaged, this, static_cast<void (CompositorWindow::*)()>(&CompositorWindow::update));
-    connect(surface, &ShellSurfaceInterface::destroyed, this,
-        [surface, this] {
-            m_stackingOrder.removeAll(surface);
-            updateFocus();
-            update();
-        }
-    );
+    connect(surface, &ShellSurfaceInterface::destroyed, this, [surface, this] {
+        m_stackingOrder.removeAll(surface);
+        updateFocus();
+        update();
+    });
     updateFocus();
 }
 
@@ -155,11 +133,9 @@ void CompositorWindow::updateFocus()
     if (!m_seat || m_stackingOrder.isEmpty()) {
         return;
     }
-    auto it = std::find_if(m_stackingOrder.constBegin(), m_stackingOrder.constEnd(),
-        [](ShellSurfaceInterface *s) {
-            return s->surface()->buffer() != nullptr;
-        }
-    );
+    auto it = std::find_if(m_stackingOrder.constBegin(), m_stackingOrder.constEnd(), [](ShellSurfaceInterface *s) {
+        return s->surface()->buffer() != nullptr;
+    });
     if (it == m_stackingOrder.constEnd()) {
         return;
     }
@@ -167,7 +143,7 @@ void CompositorWindow::updateFocus()
     m_seat->setFocusedKeyboardSurface((*it)->surface());
 }
 
-void CompositorWindow::setSeat(const QPointer< KWayland::Server::SeatInterface > &seat)
+void CompositorWindow::setSeat(const QPointer<KWayland::Server::SeatInterface> &seat)
 {
     m_seat = seat;
 }
@@ -256,8 +232,7 @@ int main(int argc, char **argv)
 
     QCommandLineParser parser;
     parser.addHelpOption();
-    QCommandLineOption xwaylandOption(QStringList{QStringLiteral("x"), QStringLiteral("xwayland")},
-                                      QStringLiteral("Start a rootless Xwayland server"));
+    QCommandLineOption xwaylandOption(QStringList{QStringLiteral("x"), QStringLiteral("xwayland")}, QStringLiteral("Start a rootless Xwayland server"));
     parser.addOption(xwaylandOption);
     parser.process(app);
 
@@ -297,7 +272,9 @@ int main(int argc, char **argv)
             exit(1);
         }
 
-        QtConcurrent::run([pipe] { readDisplayFromPipe(pipe); });
+        QtConcurrent::run([pipe] {
+            readDisplayFromPipe(pipe);
+        });
     }
 
     return app.exec();
